@@ -1,6 +1,6 @@
 from abc import ABC, abstractmethod
 from .utils import input_or_output, get_asset_property
-
+import logging
 
 class Dataset(ABC):
 
@@ -33,4 +33,9 @@ class Dataset(ABC):
         pass
 
     def get_storage_type(self):
-        return get_asset_property(asset_name=self.name, property="storage_type")
+        storage_type = get_asset_property(asset_name=self.name, property="storage_type")
+        if storage_type is not None:
+            return storage_type
+        else:
+            logging.warning("Running locally.")
+            return "FileSystem" 
