@@ -21,6 +21,6 @@ def init_spark():
 
 
 def get_path(name):
-    df = ds_initializer.load_dataset(sc=init_spark(), name=name read_all=False)
+    df = ds_initializer.load_dataset(sc=init_spark(), name=name, read_all=False)
     return from_spark_to_pandas_df_using_disk(df)
 
